Index: chrome/browser/tab_contents/infobar_delegate.h |
diff --git a/chrome/browser/tab_contents/infobar_delegate.h b/chrome/browser/tab_contents/infobar_delegate.h |
index ea56a1e3cd55b9ccd2305d15b02b89ee2a8fe887..dd1247263ecb96ee28694ca0cb4924a4157ce633 100644 |
--- a/chrome/browser/tab_contents/infobar_delegate.h |
+++ b/chrome/browser/tab_contents/infobar_delegate.h |
@@ -52,8 +52,8 @@ class InfoBarDelegate { |
virtual bool EqualsDelegate(InfoBarDelegate* delegate) const; |
// Returns true if the InfoBar should be closed automatically after the page |
// is navigated. The default behavior is to return true if the page is |
// navigated somewhere else or reloaded. |
virtual bool ShouldExpire( |
const NavigationController::LoadCommittedDetails& details) const; |
@@ -91,6 +91,10 @@ class InfoBarDelegate { |
// be expired from |contents_|. |
void StoreActiveEntryUniqueID(TabContents* contents); |
+ // Returns true if the navigation is to a new URL or a reload occured. |
+ bool ShouldExpireInternal( |
+ const NavigationController::LoadCommittedDetails& details) const; |
+ |
private: |
// The unique id of the active NavigationEntry of the TabContents that we were |
// opened for. Used to help expire on navigations. |
@@ -52,8 +52,8 @@ class InfoBarDelegate { |
virtual bool EqualsDelegate(InfoBarDelegate* delegate) const; |
// Returns true if the InfoBar should be closed automatically after the page |
- // is navigated. The default behavior is to return true if the page is |
- // navigated somewhere else or reloaded. |
+ // is navigated. The default behavior is to return true if the user initiated |
+ // navigation somewhere else or reloaded. |
virtual bool ShouldExpire( |
const NavigationController::LoadCommittedDetails& details) const; |